@@ -21,12 +21,13 @@
  */
 
 #include <glib.h>
-#include <dbus/dbus-glib.h>
+#include <gio/gio.h>
 
-gboolean _get_using_ntp_suse  (DBusGMethodInvocation   *context);
-gboolean _set_using_ntp_suse  (DBusGMethodInvocation   *context,
+gboolean _get_using_ntp_suse  (GDBusMethodInvocation   *invocation,
+                               gboolean                *can_use_ntp,
+                               gboolean                *is_using_ntp);
+gboolean _set_using_ntp_suse  (GDBusMethodInvocation   *invocation,
                                gboolean                 using_ntp);
-gboolean _update_etc_sysconfig_clock_suse
-                                (DBusGMethodInvocation *context,
-                                 const char            *key,
-                                 const char            *value);
+gboolean _update_etc_sysconfig_clock_suse (GDBusMethodInvocation *invocation,
+                                           const char            *key,
+                                           const char            *value);
